==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-metrics-plugin/eventmesh-metrics-prometheus/src/test/java/org/apache/eventmesh/metrics/prometheus/config/PrometheusConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.metrics.prometheus.config;

import org.apache.eventmesh.metrics.api.MetricsPluginFactory;
import org.apache.eventmesh.metrics.prometheus.PrometheusMetricsRegistry;

import org.junit.Assert;
import org.junit.Test;

public class PrometheusConfigurationTest {

    @Test
    public void getConfigWhenPrometheusMetricsRegistryInit() {
        PrometheusMetricsRegistry registry =
            (PrometheusMetricsRegistry) MetricsPluginFactory.getMetricsRegistry("prometheus");

        PrometheusConfiguration config = registry.getClientConfiguration();
        assertConfig(config);
    }

    private void assertConfig(PrometheusConfiguration config) {
        Assert.assertEquals(config.getEventMeshPrometheusPort(), 19091);
    }
}

==> apache-eventmesh-1.11.0-source.tar.gz: apache-eventmesh-1.11.0-src/eventmesh-metrics-plugin/eventmesh-metrics-prometheus/src/test/java/org/apache/eventmesh/metrics/prometheus/config/PrometheusConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.metrics.prometheus.config;

import org.apache.eventmesh.metrics.api.MetricsPluginFactory;
import org.apache.eventmesh.metrics.prometheus.PrometheusMetricsRegistry;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class PrometheusConfigurationTest {

    @Test
    public void getConfigWhenPrometheusMetricsRegistryInit() {
        PrometheusMetricsRegistry registry =
            (PrometheusMetricsRegistry) MetricsPluginFactory.getMetricsRegistry("prometheus");

        PrometheusConfiguration config = registry.getClientConfiguration();
        assertConfig(config);
    }

    private void assertConfig(PrometheusConfiguration config) {
        Assertions.assertEquals(config.getEventMeshPrometheusPort(), 19091);
    }
}
